<?php

namespace App\Http\Controllers;

use App\Models\Link;
use App\Models\Main;
use App\Models\Step;
use Exception;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Str;

class MainController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $steps = config('custom.stepsHome');

       return view('welcome')->with('steps', $steps);
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request){
    try {

         // Validate that the 'target_url' field is not empty
         $request->validate([
            'target_url' => 'required',
        ]);


        // Start a transaction
        DB::beginTransaction();

        // Access the 'target_url' field
        $targetUrl = $request->input('target_url');

        // We generate the random slug for the LINK
        $randomString = Str::random(8); // Generate a random string of 8 characters
        $slug = Str::slug($randomString); // Convert the string to a slug

        // Create a new record in the 'links' table
        $link = new Link();
        $link->url_target = $targetUrl; // Assign the value of the 'target_url' field
        $link->url_link = $slug; // Assign the value to the SLUG of the link with the variable $slug
        $link->save();

        // Get the ID of the newly created link
        $linkId = $link->getKey();

        // Access step data and their URLs
        $steps = $request->input('step');
        $urls = $request->input('step_url');

        // Define the association between the steps and the corresponding URLs
        $stepToUrlMap = config('custom.StepsUrls');

        // Iterate over step data
        foreach ($steps as $key => $step) {
            $url = $urls[$key];

            // Check if the step is defined in the stepToUrlMap array
            if (isset($stepToUrlMap[$step])) {
                $expectedUrls = (array) $stepToUrlMap[$step]; // Convert to array if it is a single string
                $matched = false;
                // Check if the URL of the step matches any of the expected URLs
                foreach ($expectedUrls as $expectedUrl) {
                    if ($expectedUrl !== '' && strpos($url, $expectedUrl) !== false) {
                        $matched = true;
                        break;
                    }
                }
                if ($matched) {
                    // Create a new record in the 'steps' table
                    $newStep = new Step();
                    $newStep->order = $key + 1; // Assign an order value, you can adjust it as you need
                    $newStep->action = $step; // Assign a value for the action if necessary
                    $newStep->text = 'adasdasdas';
                    $newStep->url_step = $url;
                    $newStep->link_id = $linkId; // Assign the link ID
                    $newStep->save();
                } else {
                    // The step URL does not contain any of the expected URLs, throw an exception
                    throw new Exception("El paso <b>'$step'</b> no coincide con la URL ingresada o está vacía.");
                }
            } else {
                // The step is not defined in the stepToUrlMap array, throw an exception
                throw new Exception("El paso '$step' no está definido en el mapeo de pasos.");
            }
        }

        // If we get here, all the steps were saved correctly and we can confirm the transaction
        DB::commit();

        // Build the full URL for the link
        $fullUrl = url('/link/' . $slug); // Build the full URL using the LinkId and domain of the site

        // Return the full URL as part of the response
        return response()->json(['url' => $fullUrl], 200);

    } catch (Exception $e) {
        // If any error occurs, we roll back the transaction
        DB::rollback();
        // Return the exception as part of the response
        return response()->json(['error' => $e->getMessage()], 500);
    }
}


    /**
     * Display the specified resource.
     */
    public function show($slug)
    {

      // Search the link by its slug
        $link = Link::where('url_link', $slug)->firstOrFail();

        // Get all the steps associated with this link
        $steps = $link->steps;

        // Define the association arrangement between step actions and their corresponding values
        $stepMappings = config('custom.step_mappings');

        // Associate each step action with its corresponding value from the $stepMappings array
        $stepsWithValues = [];
        foreach ($steps as $step) {
            // Check if the step action is defined in the $stepMappings array
            if (array_key_exists($step->action, $stepMappings)) {
                // Get the title and subtitle corresponding to the action
                $title = $stepMappings[$step->action][0];
                $subtitle = $stepMappings[$step->action][1];
                $icon = $stepMappings[$step->action][2];
                $color = $stepMappings[$step->action][3];
                // Associate the step action with its corresponding value and add it to the $stepsWithValues ​​array
                $stepsWithValues[] = [
                    'action' => $title,
                    'subtitle' => $subtitle,
                    'icon' => $icon,
                    'color'=> $color,
                    'url' => $step->url_step // If this is the correct field for the step URL, otherwise adjust as necessary
                ];
            }
        }

    // Pass the data to the view
    return view('links.show', ['link' => $link, 'steps' => $steps, 'stepsWithValues' => $stepsWithValues]);
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(Main $main)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, Main $main)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(Main $main)
    {
        //
    }
}
