import './bootstrap';

// Function to toggle the menu between desktop and mobile mode
document.addEventListener('DOMContentLoaded', function() {
    const desktopMenuToggle = document.getElementById('desktop-menu-toggle');
    const mobileMenuToggle = document.getElementById('mobile-menu-toggle');
    const desktopMenuDropdown = document.getElementById('desktop-menu-dropdown');
    const mobileMenu = document.getElementById('mobile-menu');

    desktopMenuToggle.addEventListener('click', function() {
        toggleMenu('desktop');
    });

    mobileMenuToggle.addEventListener('click', function() {
        toggleMenu('mobile');
    });

    function toggleMenu(menuType) {
        if (menuType === 'desktop') {
            if (desktopMenuDropdown.classList.contains("hidden")) {
                // Open the menu and change the icon to X
                desktopMenuDropdown.classList.remove("hidden");
                desktopMenuDropdown.classList.add("block");
                desktopMenuToggle.innerHTML = '<span class="sr-only">Close main menu</span><svg class="block h-8 w-8" fill="none" viewBox="0 0 24 24" stroke-width="1.5" stroke="currentColor" aria-hidden="true"><path stroke-linecap="round" stroke-linejoin="round" d="M6 18L18 6M6 6l12 12" /></svg>';
            } else {
                // Close the menu and restore the original icon
                desktopMenuDropdown.classList.remove("block");
                desktopMenuDropdown.classList.add("hidden");
                desktopMenuToggle.innerHTML = '<span class="sr-only">Open main menu</span><svg class="block h-8 w-8" fill="none" viewBox="0 0 24 24" stroke-width="1.5" stroke="currentColor" aria-hidden="true"><path stroke-linecap="round" stroke-linejoin="round" d="M3.75 6.75h16.5M3.75 12h16.5m-16.5 5.25h16.5" /></svg>';
            }
        } else if (menuType === 'mobile') {
            if (mobileMenu.classList.contains("hidden")) {
                // Open the menu and change the icon to X
                mobileMenu.classList.remove("hidden");
            } else {
                // Close the menu and restore the original icon
                mobileMenu.classList.add("hidden");
            }
        }
    }
});


// Javascript to copy the generated link after creating it
document.addEventListener('DOMContentLoaded', function() {
    // Select copy button
    const copyButton = document.getElementById('copyButton');
    // Select input to copy
    const linkInput = document.getElementById('linkInput');

    // Add click event to copy button
    copyButton.addEventListener('click', () => {
        // Select input and copy its value to clipboard
        linkInput.select();
        document.execCommand('copy');

        // Show success message
        const successMessage = document.getElementById('success-message');
        successMessage.classList.remove('hidden');
        setTimeout(() => {
            successMessage.classList.add('hidden');
        }, 1500); // Hide message after 1.5 seconds
    });
});

// Javascript to handle creation and deletion of steps in the form
document.addEventListener('DOMContentLoaded', function() {
    // Select form elements
    const addStepButton = document.getElementById('add_step');
    const removeStepButton = document.getElementById('remove_step');
    const stepsContainer = document.getElementById('steps');
    const mainSelects = document.querySelectorAll('#steps select');
    let stepCount = 1; // Step counter

    // Add click event to add step button
    addStepButton.addEventListener('click', function() {
        const newStep = createStep(); // Create new step
        const newSelects = newStep.querySelectorAll('select');

        // Copy options from main selects to selects in new step
        mainSelects.forEach((mainSelect, index) => {
            const newSelect = newSelects[index];
            newSelect.innerHTML = mainSelect.innerHTML;
        });

        stepsContainer.appendChild(newStep); // Add new step to container
        stepCount++; // Increment step counter
        updateRemoveButtonState(); // Update "Remove Step" button state
    });

    // Add click event to remove step button
    removeStepButton.addEventListener('click', function() {
        if (stepCount > 1) {
            stepsContainer.lastElementChild.remove(); // Remove last step
            stepCount--; // Decrement step counter
            updateRemoveButtonState(); // Update "Remove Step" button state
        }
    });

    // Function to create a new step
    function createStep() {
        const step = document.createElement('div');
        step.classList.add('step', 'flex', 'flex-col', 'py-1');

        // HTML for new step
        step.innerHTML = `
          <div class="py-1">
              <label for="" class="mb-2 text-md font-semibold text-black">Step Text</label>
              <select name="step[]" class="bg-white border border-gray-300 text-gray-900 text:md sm:text-lg rounded-lg focus:ring-blue-500 focus:border-blue-500 block w-full p-2.5">
                  <option value="">Select action</option>
                  <option value="CO">Colombia</option>
                  <option value="MX">México</option>
                  <option value="ES">España</option>
                  <option value="US">Estados Unidos</option>
              </select>
          </div>

          <div class="py-2">
              <label for="" class="mb-2 text-md font-semibold text-black">Step URL</label>
              <input type="url" name="step_url[]" class="bg-white border border-gray-300 text-gray-900 text:md sm:text-lg rounded-lg focus:ring-blue-500 focus:border-blue-500 block w-full p-2.5" placeholder="https://...">
          </div>
      `;

        step.classList.add('new-step'); // Add class for CSS animation
        return step;
    }

    // Function to update "Remove Step" button state
    function updateRemoveButtonState() {
        if (stepCount === 1) {
            removeStepButton.disabled = true; // Disable button if only one step
            removeStepButton.classList.add('disabled:opacity-50', 'cursor-not-allowed');
        } else {
            removeStepButton.disabled = false; // Enable button if more than one step
            removeStepButton.classList.remove('disabled:opacity-50', 'cursor-not-allowed');
        }
    }
});

// Javascript for handling form submission and showing generated link
$(document).ready(function() {
    $('#submitForm').click(function() {
        // Get form data
        var formData = $('#linkForm').serialize();

        // Send AJAX request to backend
        $.ajax({
            type: 'POST',
            url: $('#linkForm').attr('action'),
            data: formData,
            success: function(response) {
                // Check if response contains a URL
                if (response.url) {
                    // Show URL to user
                    $('#responseMessage').html('').hide();
                    $('#linkInput').val(response.url); // Show generated link in input
                    $('#successModal').removeClass('hidden'); // Show modal with URL
                } else {
                    // Show generic message if response does not have a URL
                    $('#responseMessage').html('').hide();
                }
            },
            error: function(xhr, status, error) {
                // Show error message to user
                var errorMessage = "An error occured: ";
                if (xhr.responseJSON && xhr.responseJSON.error) {
                    errorMessage += xhr.responseJSON.error;
                    $('#responseMessage').html(errorMessage).show();
                } else {
                    errorMessage += error;
                    $('#responseMessage').html(errorMessage).show();
                }
            }
        });
    });

    // Close modal when close button is clicked
    $('#closeModal').click(function() {
        $('#successModal').addClass('hidden');
    });
});

// Javascript for unlocking links after visiting all steps
document.addEventListener('DOMContentLoaded', function() {
    // Visited links count
    let visitedLinksCount = 0;

    // Target URL button
    const targetUrlBtn = document.getElementById('target-url-btn');

    // Function to handle step button click
    function handleStepButtonClick(event) {
        // Exit function if button is already disabled
        if (this.classList.contains('opacity-50')) {
            return;
        }

        // Increment visited links count
        visitedLinksCount++;

        // Disable button and add opacity style class
        this.classList.add('opacity-50', 'cursor-not-allowed');

        // Open link in new window or tab
        window.open(this.dataset.url, '_blank');

        // Check if all step links have been visited
        if (visitedLinksCount === stepsWithValues.length) {
            // Wait for 3 seconds before enabling target URL button
            setTimeout(() => {
                targetUrlBtn.classList.remove('opacity-50', 'cursor-not-allowed');
                targetUrlBtn.removeAttribute('disabled');
                targetUrlBtn.addEventListener('click', () => {
                    window.location.href = targetUrlBtn.dataset.url;
                });
            }, 3000); // 3 seconds delay
        }
    }

    // Add event listener for clicks on step buttons
    const stepButtons = document.querySelectorAll('.step-btn');
    stepButtons.forEach(button => {
        button.addEventListener('click', handleStepButtonClick);
    });

    // Set target URL on target URL button
    targetUrlBtn.dataset.url = targetUrl;
});
